@@ -33,18 +33,14 @@ public class IconEntry extends VBox {
 	 * Construct a new IconEntry
 	 */
 	public IconEntry(String historyId, String dialogTitle) {
-		setHandle(gnome_icon_entry_new(historyId, dialogTitle));
-		initializeEventHandlers();
+		super(gnome_icon_entry_new(historyId, dialogTitle));
 	}
 	
 	/**
 	 * Construct a new IconEntry from a handle to a native resource.
 	 */
 	public IconEntry(int handle) {
-	    setHandle(handle);
-	}
-	
-	protected void noopInit() {
+	    super(handle);
 	}
 	
 	/**
@@ -110,6 +106,8 @@ public class IconEntry extends VBox {
 		int i = findListener(listeners, listener);
 		if (i == -1) {
 			if (null == listeners) {
+				evtMap.initialize(this, IconEntryEvent.Type.BROWSE);
+				evtMap.initialize(this, IconEntryEvent.Type.CHANGED);
 				listeners = new Vector();
 			}
 			listeners.addElement(listener);
@@ -125,6 +123,8 @@ public class IconEntry extends VBox {
 			listeners.remove(i);
 		}
 		if (0 == listeners.size()) {
+			evtMap.uninitialize(this, IconEntryEvent.Type.BROWSE);
+			evtMap.uninitialize(this, IconEntryEvent.Type.CHANGED);
 			listeners = null;
 		}
 	}
@@ -150,17 +150,16 @@ public class IconEntry extends VBox {
 		fireIconEntryEvent(new IconEntryEvent(this, IconEntryEvent.Type.BROWSE));
 	}
 	
-	protected void initializeEventHandlers() {
-		super.initializeEventHandlers();
-		evtMap.initialize(this);
-	}
-
 	public Class getEventListenerClass(String signal) {
-		return evtMap.getListenerClass(signal);
+		Class cls = evtMap.getEventListenerClass(signal);
+		if (cls == null) cls = super.getEventListenerClass(signal);
+		return cls;
 	}
 
 	public GtkEventType getEventType(String signal) {
-		return evtMap.getEventType(signal);
+		GtkEventType et = evtMap.getEventType(signal);
+		if (et == null) et = super.getEventType(signal);
+		return et;
 	}
 
 	private static EventMap evtMap = new EventMap();
